"use strict";
//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PageHead = void 0;
var react_1 = __importDefault(require("react"));
var head_1 = __importDefault(require("next/head"));
var next_seo_1 = require("next-seo");
var core_1 = require("primeobjects-helper-util/build/cjs/core");
var solution_1 = require("primeobjects-helper-ui/build/cjs/hooks/solution");
var lodash_1 = require("lodash");
//learn more about the The Open Graph protocol,  https://ogp.me/
var PageHead = function (props) {
    var _a, _b, _c;
    var url = props.url, children = props.children, domain = props.domain, port = props.port;
    var solution = (0, solution_1.useSolution)();
    var site = (solution === null || solution === void 0 ? void 0 : solution.site) ? solution.site : {};
    var noIndex = props.noIndex == true;
    var noFollow = props.noFollow == true;
    var titleAppendSiteName = props.titleAppendSiteName == true;
    var jsList = props.jsList ? props.jsList : [];
    var cssList = props.cssList ? props.cssList : [];
    var protocol = domain.indexOf("localhost") >= 0 ? "http" : "https";
    var type = props.type ? props.type : "website";
    var author = (0, core_1.isNonEmptyString)(props.author) ? props.author : site.author;
    var siteName = site.name;
    var canonical = (0, core_1.isNonEmptyString)(props.canonical)
        ? props.canonical
        : "".concat(protocol, "://").concat(domain).concat((0, core_1.isNonEmptyString)(url) ? url : "");
    var headManifestUrl = domain.indexOf("localhost") >= 0
        ? "".concat(protocol, "://").concat(domain).concat(port ? ":" + port : "")
        : "".concat(protocol, "://").concat(domain);
    var image = (0, core_1.isNonEmptyString)(props.image)
        ? { url: props.image }
        : (0, core_1.isNonEmptyString)(site.image)
            ? { url: site.image }
            : site.image;
    if (image && (0, core_1.isNonEmptyString)(image === null || image === void 0 ? void 0 : image.url) && (image === null || image === void 0 ? void 0 : image.url.indexOf("/")) == 0)
        image.url = "".concat(protocol, "://").concat(domain).concat(image.url);
    var title = (0, core_1.isNonEmptyString)(props.title) ? props.title : (_a = site === null || site === void 0 ? void 0 : site.title) !== null && _a !== void 0 ? _a : "";
    if (title.length > 120)
        title = title.substring(0, 120) + " ...";
    if (titleAppendSiteName)
        title = title + " - ".concat(site.name);
    var description = !(0, lodash_1.isNil)(props.description)
        ? props.description
        : site.description;
    if ((0, lodash_1.isNil)(description))
        description = "";
    if (description.length > 150)
        description = description.substring(0, 150) + " ...";
    var keywords = (0, core_1.isNonEmptyString)(props.keywords)
        ? props.keywords
        : site.keywords;
    var twitterSite = (0, core_1.isNonEmptyString)(props.twitterSite)
        ? (0, core_1.isNonEmptyString)(props.twitterSite)
        : (0, core_1.isNonEmptyString)(site.twitterSite)
            ? site.twitterSite
            : null;
    var twitterHandle = (0, core_1.isNonEmptyString)(props.twitterHandle)
        ? (0, core_1.isNonEmptyString)(props.twitterHandle)
        : (0, core_1.isNonEmptyString)(site.twitterHandle)
            ? site.twitterHandle
            : null;
    var facebook = (0, core_1.isObject)(site.facebook) ? site.facebook : props.facebook;
    var gtag = site.googleTagManagerId &&
        "\n        window.dataLayer = window.dataLayer || [];\n        function gtag(){dataLayer.push(arguments);}\n        gtag(\"js\", new Date());\n        gtag(\"config\", \"".concat(site.googleTagManagerId, "\");\n    ");
    var locale = props.locale ? props.locale : "en_GB";
    var renderJSList = function () {
        return (0, lodash_1.map)(jsList, function (l, idx) {
            return (0, core_1.isNonEmptyString)(l) ? (react_1.default.createElement("script", { key: idx, src: l })) : (react_1.default.createElement("script", { key: idx, src: l.href, integrity: l.integrity, crossOrigin: l.crossOrigin }));
        });
    };
    var renderCSSList = function () {
        return (0, lodash_1.map)(cssList, function (l, idx) {
            return (0, core_1.isNonEmptyString)(l) ? (react_1.default.createElement("link", { key: idx, href: l, rel: "stylesheet" })) : (react_1.default.createElement("link", { key: idx, href: l.href, integrity: l.integrity, crossOrigin: l.crossOrigin, rel: "stylesheet" }));
        });
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(next_seo_1.NextSeo, { title: title, description: description, canonical: canonical, openGraph: {
                // videos?: ReadonlyArray<OpenGraphMedia>;
                // audio?: ReadonlyArray<OpenGraphMedia>;
                // defaultImageHeight?: number;
                // defaultImageWidth?: number;
                locale: locale,
                type: type,
                // profile?: OpenGraphProfile;
                // book?: OpenGraphBook;
                // article?: OpenGraphArticle;
                // video?: OpenGraphVideo;
                url: canonical,
                title: title,
                description: description,
                images: (image === null || image === void 0 ? void 0 : image.url)
                    ? [
                        {
                            url: image.url,
                            width: image.width,
                            height: image.height,
                            alt: (_b = image.alt) !== null && _b !== void 0 ? _b : title,
                            type: (_c = image.type) !== null && _c !== void 0 ? _c : "image/jpeg"
                        }
                    ]
                    : [],
                siteName: siteName
            }, twitter: {
                handle: twitterHandle,
                site: twitterSite,
                cardType: (image === null || image === void 0 ? void 0 : image.url) ? "summary_large_image" : "summary"
            }, noindex: noIndex, nofollow: noFollow }),
        react_1.default.createElement(head_1.default, null,
            react_1.default.createElement("meta", { charSet: "utf-8" }),
            react_1.default.createElement("meta", { httpEquiv: "X-UA-Compatible", content: "IE=edge" }),
            react_1.default.createElement("meta", { name: "viewport", content: "width=device-width, initial-scale=1, shrink-to-fit=no" }),
            react_1.default.createElement("meta", { name: "msvalidate.01", content: site.bingVerifySite }),
            keywords && react_1.default.createElement("meta", { name: "keywords", content: keywords }),
            author && react_1.default.createElement("meta", { name: "author", content: author }),
            (facebook === null || facebook === void 0 ? void 0 : facebook.domainVerification) && (react_1.default.createElement("meta", { name: "facebook-domain-verification", content: facebook.domainVerification })),
            type == "article" && (facebook === null || facebook === void 0 ? void 0 : facebook.name) && (react_1.default.createElement("meta", { property: "article:publisher", content: "https://www.facebook.com/".concat(facebook.name, "/") })),
            type == "article" &&
                (facebook === null || facebook === void 0 ? void 0 : facebook.name) &&
                (facebook === null || facebook === void 0 ? void 0 : facebook.publishedOn) && (react_1.default.createElement("meta", { property: "article:modified_time", content: facebook.publishedOn })),
            react_1.default.createElement("link", { rel: "icon", type: "image/svg+xml", href: "".concat(headManifestUrl, "/logo.svg") }),
            react_1.default.createElement("link", { rel: "apple-touch-icon", sizes: "180x180", href: "".concat(headManifestUrl, "/favicon-180x180.png") }),
            react_1.default.createElement("link", { rel: "icon", type: "image/png", sizes: "32x32", href: "".concat(headManifestUrl, "/favicon-32x32.png") }),
            react_1.default.createElement("link", { rel: "icon", type: "image/png", sizes: "16x16", href: "".concat(headManifestUrl, "/favicon-16x16.png") }),
            react_1.default.createElement("link", { rel: "mask-icon", href: "".concat(headManifestUrl, "/safari-pinned-tab.svg"), color: site.tileColor ? site.tileColor : site.themeColor }),
            react_1.default.createElement("meta", { name: "msapplication-TileColor", content: site.tileColor ? site.tileColor : site.themeColor }),
            react_1.default.createElement("link", { rel: "manifest", href: "/site.webmanifest" }), "<!--[if lt IE 9]>", "  <script src=\"https://oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js\"></script>", "  <script src=\"https://oss.maxcdn.com/respond/1.4.2/respond.min.js\"></script>", "<![endif]--></link>",
            site.googleTagManagerId && (react_1.default.createElement("script", { async: true, src: "https://www.googletagmanager.com/gtag/js?id=".concat(site.googleTagManagerId) })),
            gtag && react_1.default.createElement("script", { dangerouslySetInnerHTML: { __html: gtag } }),
            renderJSList(),
            renderCSSList(),
            react_1.default.createElement("link", { href: "/css/globals.css", rel: "stylesheet" }),
            children)));
};
exports.PageHead = PageHead;
exports.default = exports.PageHead;
//# sourceMappingURL=head.js.map