//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { useEffect, useState, useRef } from "react";
import { callApi } from "./auth-call-api";
import { isFunction, isBoolean, cloneDeep } from "lodash";
import { isSSR, isNonEmptyString, isObject, getCache, setCache, getWindow, setColorTheme } from "primeobjects-helper-util";
import { useContextStore } from "primeobjects-ui-web-store";
import { getCurrentPoolUser } from "./auth-cognito";
import { getApiEndpoint } from "../util";
import { libTrackIsOn } from "primeobjects-helper-util/build/cjs/core";
import { setPrimaryColor } from "primeobjects-helper-ui";
export var useCurrentContext = function (solution, settings) {
    var _a = useState(undefined), context = _a[0], setContext = _a[1];
    var loading = useRef("");
    var refresh = settings === null || settings === void 0 ? void 0 : settings.refresh;
    var contextStore = useContextStore();
    var SSR = isSSR();
    if (!(solution === null || solution === void 0 ? void 0 : solution.id)) {
        console.error("There's no solution provided for context.");
    }
    var onError = function (error) {
        console.error(error);
        setContext(undefined);
        if (settings === null || settings === void 0 ? void 0 : settings.onError) {
            settings === null || settings === void 0 ? void 0 : settings.onError(error);
        }
        else {
            if (settings &&
                settings.signInUrl &&
                isNonEmptyString(settings === null || settings === void 0 ? void 0 : settings.signInUrl)) {
                getWindow().location.replace(settings.signInUrl);
            }
        }
    };
    var processResult = function (result, settings) {
        var _a, _b;
        var settingContext = isObject(settings === null || settings === void 0 ? void 0 : settings.context)
            ? cloneDeep(settings === null || settings === void 0 ? void 0 : settings.context)
            : {};
        var currentContext = result.context;
        if (isObject(settingContext.recordByMembership)) {
            currentContext.recordByMembership = __assign(__assign({}, (isObject(currentContext.recordByMembership)
                ? currentContext.recordByMembership
                : {})), settingContext.recordByMembership);
        }
        if (isObject(settingContext.organization)) {
            currentContext.organization = __assign(__assign({}, (isObject(currentContext.organization)
                ? currentContext.organization
                : {})), settingContext.organization);
        }
        if ((_b = (_a = currentContext.organization) === null || _a === void 0 ? void 0 : _a.color) === null || _b === void 0 ? void 0 : _b.name) {
            setColorTheme(currentContext.organization.color.name, currentContext.organization.color);
            setPrimaryColor(currentContext.organization.color);
        }
        if (isObject(settingContext.user)) {
            currentContext.user = __assign(__assign({}, (isObject(currentContext.user) ? currentContext.user : {})), settingContext.user);
        }
        if (isObject(settingContext.solution)) {
            currentContext.solution = __assign(__assign({}, (isObject(currentContext.solution)
                ? currentContext.solution
                : {})), settingContext.solution);
        }
        setContext(currentContext);
        if (isFunction(settings === null || settings === void 0 ? void 0 : settings.onSuccess)) {
            settings === null || settings === void 0 ? void 0 : settings.onSuccess(currentContext);
        }
        return currentContext;
    };
    var getCurrentContext = function (key) {
        var newSettings = cloneDeep(settings
            ? settings
            : {
                signInUrl: "/auth/sign-in",
                needAuthorization: true,
                onSuccess: null,
                onError: null
            });
        if (!isBoolean(newSettings.needAuthorization)) {
            newSettings.needAuthorization = true;
        }
        if (!isBoolean(newSettings.needSolution)) {
            newSettings.needSolution = true;
        }
        var apiParams = {
            needAuthorization: newSettings.needAuthorization == true,
            skipAuthentication: newSettings.skipAuthentication == true,
            needSolution: newSettings.needSolution == true
        };
        if (isNonEmptyString(newSettings.recordId))
            apiParams.recordId = newSettings.recordId;
        if (isNonEmptyString(newSettings.recordIdByMembership))
            apiParams.recordIdByMembership = newSettings.recordIdByMembership;
        if (isNonEmptyString(newSettings.needRecord))
            apiParams.needRecord = newSettings.needRecord;
        if (isNonEmptyString(newSettings.needRecordByMembership))
            apiParams.needRecordByMembership =
                newSettings.needRecordByMembership;
        var cacheKey = "currentContext-".concat(key, "-").concat(apiParams.recordId, "-").concat(apiParams.recordIdByMembership, "-").concat(apiParams.skipAuthentication, "-").concat(apiParams.needAuthorization, "-").concat(apiParams.needRecord, "-").concat(apiParams.needRecordByMembership, "-").concat(apiParams.needSolution, "-").concat(refresh);
        var cacheResult = getCache(cacheKey);
        if (cacheResult) {
            processResult(cacheResult, newSettings);
        }
        else {
            if (loading.current != cacheKey) {
                loading.current = cacheKey;
                callApi(solution, newSettings.apiUrl
                    ? newSettings.apiUrl
                    : getApiEndpoint(solution, "solution", "current-context"), apiParams, "GET")
                    .then(function (result) {
                    setCache(cacheKey, result);
                    if (libTrackIsOn()) {
                        console.log({
                            currentContext: cacheKey,
                            componentName: settings === null || settings === void 0 ? void 0 : settings.componentName
                        });
                    }
                    contextStore.setData(processResult(result, newSettings));
                })
                    .catch(function (error) {
                    onError(error);
                })
                    .finally(function () {
                    loading.current = "";
                });
            }
        }
    };
    useEffect(function () {
        if (!context && !SSR && solution.id) {
            getCurrentPoolUser(solution).then(function (result) {
                if (result) {
                    getCurrentContext("".concat(solution.id, ".").concat(result.username));
                }
                else {
                    onError("getCurrentPoolUser");
                }
            });
        }
    }, [SSR, refresh, solution.id]);
    return context ? context : {};
};
//# sourceMappingURL=use-current-context.js.map